/*
 * Storm.java
 *
 * Created on November 8, 2004, 1:14 PM
 */

/**
 * Storm is a simple class that contains storm data for each storm in a radar's
 * storm table.  It also contains accessors for setting and returning this data.
 * @author Andrew T. Flowers, K0SM
 */


public class Storm {
    private String id;
    private String radar;
    private double lat;
    private double lon;
    private String tvs;
    private String meso;
    private int posh;
    private int poh;
    private double mxsize;
    private int vil;
    private int dbz;
    private double ht;
    private double top;
    private int speed;
    private int direction;
    private long time;
    
    /** Creates a new instance of Storm */
    public Storm() {
    }

    /**
     * Constructs a new storm using all of the parameters to initalize it.
     * @param id alphanumeric ID of storm (assigned by radar site)
     * @param radar callsign of radar recording the storm
     * @param lat latitude of radar in degrees
     * @param lon longitude or radar in degrees
     * @param tvs Tornadic Vortex signature
     * @param meso Mesocyclone signature
     * @param posh Percent probablility of severe hail
     * @param poh Percent probablility of hail
     * @param mxsize Estimated maximum size of hail in inches
     * @param vil vertically integrated liquid water in kg/m^2
     * @param dbz maximum reflectivity of storm in dBZ
     * @param ht altitude of maximum reflectivity (1000's of feet)
     * @param top maximum altitude reporting 18dBZ or greater (1000's of feet)
     * @param direction direction the storm is moving (deg)
     * @param speed Speed at which the storm is moving (knots)
     * @param time local computer time (ms) at which this storm was recorded (not radar time)
     */    
    public Storm(String id, String radar, double lat, double lon, String tvs, String meso, int posh, int poh, 
                    double mxsize, int vil, int dbz, double ht, double top, int direction, int speed, long time) {
                        
        this.id = id;
        this.radar = radar;
        this.lat = lat;
        this.lon = lon;
        this.tvs = tvs;
        this.meso = meso;
        this.posh = posh;
        this.poh = poh;
        this.mxsize = mxsize;
        this.vil = vil;
        this.dbz = dbz;
        this.ht = ht;
        this.top = top;
        this.speed = speed;
        this.direction = direction;
        this.time = time;
    }
    /**
     * Constructs a Storm using a String[] containing all the storm attributes.
     * @param params String[] containing all attributes of the storm
     */    
    public Storm(String[] params) {
        id = params[0];
        radar = params[1];
        lat = new Double(params[2]).doubleValue();
        lon = new Double(params[3]).doubleValue();
        tvs = params[4];
        meso = params[5];
        posh = new Integer(params[6]).intValue();
        poh = new Integer(params[7]).intValue();
        mxsize = new Double(params[8]).doubleValue();
        vil = new Integer(params[9]).intValue();
        dbz = new Integer(params[10]).intValue();
        ht = new Integer(params[11]).intValue();
        top = new Integer(params[12]).intValue();
        speed = new Integer(params[13]).intValue();
        direction = new Integer(params[14]).intValue();
    }
    /**
     * Set's the alphanumeric ID of this storm.
     * @param s the alphanumber ID assigned by the radar
     */    
    public void setID(String id) {
        this.id = id;
    }
    /*
    public void setTVS(String tvs) {
        this.tvs = tvs;
    }
    public void setMSO(String meso) {
        this.meso = meso;
    }
    public void setPOSH() {
        this.posh =
    }
    public void setPOH() {
        
    }
    public void setMXSize() {
        
    }
    public void setVIL() {
        
    }
    public void setDBz() {
        
    }
    public void setHT() {
        
    }
    public void setTop() {
        
    }
    public void setSpeed() {
        
    }
    public void setDirection() {
        
    }*/
    ////////////Accessors
    /**
     * Returns the reporting radars's callsign
     * @return the radar's callsign
     */    
    public String getRadar() {
        return radar;
    }
    /**
     * Returns the alphanumeric ID of this storm
     * @return alphanumeric ID of this storm
     */    
    public String getID() {
        return id;
    }
    /**
     * Returns latitude of storm
     * @return latitude in degrees
     */    
    public double getLat() {
        return lat;
    }
    /**
     * Returns longitude of this storm
     * @return longitude in degrees
     */    
    public double getLon() {
        return lon;
    }
    /**
     * Returns the Tornadic Vortex Signature of this storm
     * @return TVS
     */    
    public String getTVS() {
        return tvs;
    }
    /**
     * Returns the mesocyclone signature of this storm.
     * @return  MESO
     */    
    public String getMSO() {
     return meso;   
    }
    /**
     * Returns the percent probability of severe hail in this storm.
     * @return  percent probability of severe hail
     */    
    public double getPOSH() {
        return posh;
    }
    /**
     * Returns the percent probability of hail in this storm.
     * @return  percent probability of hail in this storm.
     */    
    public double getPOH() {
        return poh;
    }
    /**
     * Returns estimated maximum size of hail in inches
     * @return estimated maximum size of hail in inches
     */    
    public double getMXSize() {
        return mxsize;
    }
    /**
     * Returns vertically integrated liquid water in kg/m^2
     * @return vertically integrated liquid water in kg/m^2
     */    
    public double getVIL() {
        return vil;
    }
    /**
     * Returns maximum reflectivity of this storm
     * @return max reflectivity in dBZ
     */    
    public int getDBz() {
        return dbz;
    }
    /**
     * Returns the height of reported maximum reflectivity
     * @return the height of max reflectivity in 1000's of feet
     */    
    public double getHT() {
        return ht;
    }
    /**
     * Returns the max height of the storm
     * @return the height the storm top in 1000's of feet
     */    
    public double getTop() {
        return top;
    }
    /**
     * Returns the speed of the storm movement.  This is not the same as the maximum
     * winds within the storm.
     * @return the speed of the storm in knots
     */    
    public int getSpeed() {
        return speed;
    }
    /**
     * Returns the direction of storm movement in degrees.  This direction refers to
     * where the storm is going rather than where it is coming from (this is different
     * from how this value is reported in the originating radar's text).
     * @return direction of movement in degrees, north = 0.
     */    
    public int getDirection() {
        return direction;
    }
    /**
     * returns the time at which RainScatter created this storm.  It is not the same
     * as when the storm was logged by the radar location.
     * @return time in ms from Jan 1, 1970.
     */    
    public long getTime() {
        return time;
    }
}
